==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_server/TransferServerWorkflowDetails.java <==
package com.hashicorp.cdktf.providers.aws.transfer_server;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.951Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferServer.TransferServerWorkflowDetails")
@software.amazon.jsii.Jsii.Proxy(TransferServerWorkflowDetails.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TransferServerWorkflowDetails extends software.amazon.jsii.JsiiSerializable {

    /**
     * on_upload block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/transfer_server#on_upload TransferServer#on_upload}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUpload() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<TransferServerWorkflowDetails> {
        com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload;

        /**
         * Sets the value of {@link TransferServerWorkflowDetails#getOnUpload}
         * @param onUpload on_upload block.
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/transfer_server#on_upload TransferServer#on_upload}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onUpload(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload) {
            this.onUpload = onUpload;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TransferServerWorkflowDetails}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public TransferServerWorkflowDetails build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TransferServerWorkflowDetails {
        private final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.onUpload = software.amazon.jsii.Kernel.get(this, "onUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.onUpload = builder.onUpload;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUpload() {
            return this.onUpload;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getOnUpload() != null) {
                data.set("onUpload", om.valueToTree(this.getOnUpload()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.transferServer.TransferServerWorkflowDetails"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TransferServerWorkflowDetails.Jsii$Proxy that = (TransferServerWorkflowDetails.Jsii$Proxy) o;

            return this.onUpload != null ? this.onUpload.equals(that.onUpload) : that.onUpload == null;
        }

        @Override
        public final int hashCode() {
            int result = this.onUpload != null ? this.onUpload.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/transfer_server/TransferServerWorkflowDetails.java <==
package com.hashicorp.cdktf.providers.aws.transfer_server;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:12.014Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.transferServer.TransferServerWorkflowDetails")
@software.amazon.jsii.Jsii.Proxy(TransferServerWorkflowDetails.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface TransferServerWorkflowDetails extends software.amazon.jsii.JsiiSerializable {

    /**
     * on_partial_upload block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/transfer_server#on_partial_upload TransferServer#on_partial_upload}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload getOnPartialUpload() {
        return null;
    }

    /**
     * on_upload block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/transfer_server#on_upload TransferServer#on_upload}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUpload() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<TransferServerWorkflowDetails> {
        com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload onPartialUpload;
        com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload;

        /**
         * Sets the value of {@link TransferServerWorkflowDetails#getOnPartialUpload}
         * @param onPartialUpload on_partial_upload block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/transfer_server#on_partial_upload TransferServer#on_partial_upload}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onPartialUpload(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload onPartialUpload) {
            this.onPartialUpload = onPartialUpload;
            return this;
        }

        /**
         * Sets the value of {@link TransferServerWorkflowDetails#getOnUpload}
         * @param onUpload on_upload block.
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/transfer_server#on_upload TransferServer#on_upload}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder onUpload(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload) {
            this.onUpload = onUpload;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link TransferServerWorkflowDetails}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public TransferServerWorkflowDetails build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link TransferServerWorkflowDetails}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements TransferServerWorkflowDetails {
        private final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload onPartialUpload;
        private final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload onUpload;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.onPartialUpload = software.amazon.jsii.Kernel.get(this, "onPartialUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload.class));
            this.onUpload = software.amazon.jsii.Kernel.get(this, "onUpload", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.onPartialUpload = builder.onPartialUpload;
            this.onUpload = builder.onUpload;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnPartialUpload getOnPartialUpload() {
            return this.onPartialUpload;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.transfer_server.TransferServerWorkflowDetailsOnUpload getOnUpload() {
            return this.onUpload;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getOnPartialUpload() != null) {
                data.set("onPartialUpload", om.valueToTree(this.getOnPartialUpload()));
            }
            if (this.getOnUpload() != null) {
                data.set("onUpload", om.valueToTree(this.getOnUpload()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.transferServer.TransferServerWorkflowDetails"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            TransferServerWorkflowDetails.Jsii$Proxy that = (TransferServerWorkflowDetails.Jsii$Proxy) o;

            if (this.onPartialUpload != null ? !this.onPartialUpload.equals(that.onPartialUpload) : that.onPartialUpload != null) return false;
            return this.onUpload != null ? this.onUpload.equals(that.onUpload) : that.onUpload == null;
        }

        @Override
        public final int hashCode() {
            int result = this.onPartialUpload != null ? this.onPartialUpload.hashCode() : 0;
            result = 31 * result + (this.onUpload != null ? this.onUpload.hashCode() : 0);
            return result;
        }
    }
}
